Classes and Objects - Digging a Little Deeper
:::::::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Classes and Objects - Digging Deeper
   :maxdepth: 2

   Fractions.rst
   ObjectsareMutable.rst
   Sameness.rst
   ArithmeticMethods.rst
   Glossary.rst
   Exercises.rst
